@@ -2,10 +2,12 @@ import traceback
 from asyncio.exceptions import TimeoutError
 from pathlib import Path
 
-import httpx
+import orjson
 from httpx import ConnectTimeout
 from nonebot.log import logger
 
+from ..HttpClient_pool import client_default
+
 dir_path = Path(__file__).parent
 
 
@@ -13,9 +15,8 @@ async def get_pupu_msg():
     try:
         url = "https://v1.hitokoto.cn"
         params = {}
-        async with httpx.AsyncClient() as client:
-            resp = await client.get(url, params=params, timeout=5)
-            result = resp.json()
+        resp = await client_default.get(url, params=params, timeout=5)
+        result = orjson.loads(resp.content)
         if resp.status_code == 200:
             return result["hitokoto"]
         else:
